==> TACZ-Refabricated-1.20.1-0.0.5-forge1.1.6-hotfix-sources.jar: com/tacz/guns/init/ModItems.java <==
package com.tacz.guns.init;

import com.tacz.guns.GunMod;
import com.tacz.guns.api.item.gun.GunItemManager;
import com.tacz.guns.item.*;
import net.fabricmc.fabric.api.item.v1.FabricItemSettings;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public class ModItems {
    public static void init() {
        GunItemManager.registerGunItem(ModernKineticGunItem.TYPE_NAME, MODERN_KINETIC_GUN);
    }

    public static ModernKineticGunItem MODERN_KINETIC_GUN = register("modern_kinetic_gun", new ModernKineticGunItem());

//    public static ThrowableItem M67 = register("m67", new ThrowableItem());

    public static class_1792 AMMO = register("ammo", new AmmoItem());
    public static AttachmentItem ATTACHMENT = register("attachment", new AttachmentItem());

    public static GunSmithTableItem GUN_SMITH_TABLE = register("gun_smith_table", new DefaultTableItem(ModBlocks.GUN_SMITH_TABLE));
    public static GunSmithTableItem WORKBENCH_111 = register("workbench_a", new GunSmithTableItem(ModBlocks.WORKBENCH_111));
    public static GunSmithTableItem WORKBENCH_211 = register("workbench_b", new GunSmithTableItem(ModBlocks.WORKBENCH_211));
    public static GunSmithTableItem WORKBENCH_121 = register("workbench_c", new GunSmithTableItem(ModBlocks.WORKBENCH_121));


    public static class_1792 TARGET = register("target", new class_1747(ModBlocks.TARGET, new FabricItemSettings()));
    public static class_1792 STATUE = register("statue", new class_1747(ModBlocks.STATUE, new FabricItemSettings()));
    public static class_1792 AMMO_BOX = register("ammo_box", new AmmoBoxItem());
    public static class_1792 TARGET_MINECART = register("target_minecart", new TargetMinecartItem());

    private static <T extends class_1792> T register(String name, T item) {
        return class_2378.method_10230(class_7923.field_41178, new class_2960(GunMod.MOD_ID, name), item);
    }
}

==> TACZ-Refabricated-1.21.1-0.0.2.2-forge1.1.6-hotfix-sources.jar: com/tacz/guns/init/ModItems.java <==
package com.tacz.guns.init;

import com.tacz.guns.GunMod;
import com.tacz.guns.api.item.gun.GunItemManager;
import com.tacz.guns.item.*;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public class ModItems {
    public static void init() {
        GunItemManager.registerGunItem(ModernKineticGunItem.TYPE_NAME, MODERN_KINETIC_GUN);
    }

    public static ModernKineticGunItem MODERN_KINETIC_GUN = register("modern_kinetic_gun", new ModernKineticGunItem());

//    public static ThrowableItem M67 = register("m67", new ThrowableItem());

    public static class_1792 AMMO = register("ammo", new AmmoItem());
    public static AttachmentItem ATTACHMENT = register("attachment", new AttachmentItem());

    public static GunSmithTableItem GUN_SMITH_TABLE = register("gun_smith_table", new DefaultTableItem(ModBlocks.GUN_SMITH_TABLE));
    public static GunSmithTableItem WORKBENCH_111 = register("workbench_a", new GunSmithTableItem(ModBlocks.WORKBENCH_111));
    public static GunSmithTableItem WORKBENCH_211 = register("workbench_b", new GunSmithTableItem(ModBlocks.WORKBENCH_211));
    public static GunSmithTableItem WORKBENCH_121 = register("workbench_c", new GunSmithTableItem(ModBlocks.WORKBENCH_121));


    public static class_1792 TARGET = register("target", new class_1747(ModBlocks.TARGET, new class_1792.class_1793()));
    public static class_1792 STATUE = register("statue", new class_1747(ModBlocks.STATUE, new class_1792.class_1793()));
    public static class_1792 AMMO_BOX = register("ammo_box", new AmmoBoxItem());
    public static class_1792 TARGET_MINECART = register("target_minecart", new TargetMinecartItem());

    private static <T extends class_1792> T register(String name, T item) {
        return class_2378.method_10230(class_7923.field_41178, class_2960.method_60655(GunMod.MOD_ID, name), item);
    }
}
